OC.L10N.register(
    "notes",
    {
    "Error" : "오류",
    "New note" : "새 메모",
    "Notes" : "메모",
    "Settings" : "설정",
    "There are unsaved notes. Leaving the page will discard all changes!" : "저장하지 않은 메모가 있습니다. 이 페이지를 벗어나면 변경 사항이 손실됩니다!",
    "Categories" : "분류",
    "Loading …" : "불러오는 중 …",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "This week" : "이번 주",
    "Last week" : "저번 주",
    "This month" : "이번 달",
    "Last month" : "저번 달",
    "Rename" : "이름 바꾸기",
    "Delete note" : "메모 삭제",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Add to favorites" : "즐겨찾기에 추가",
    "Details" : "세부사항",
    "Preview" : "미리 보기",
    "Edit" : "편집",
    "Category" : "분류",
    "Uncategorized" : "분류되지 않음",
    "Saving failed!" : "저장할 수 없습니다!",
    "_%n word_::_%n words_" : ["단어 %n개"],
    "Android app" : "Android 앱",
    "iOS app" : "iOS 앱"
},
"nplurals=1; plural=0;");
